@@ -25,7 +25,7 @@ class SE2(_base.MatrixLieGroup):
     """Internal parameters. `(x, y, cos, sin)`."""
 
     @overrides
-    def __repr__(self):
+    def __repr__(self) -> str:
         xy = jnp.round(self.xy_unit_complex[..., :2], 5)
         unit_complex = jnp.round(self.xy_unit_complex[..., 2:], 5)
         return f"{self.__class__.__name__}(xy={xy}, unit_complex={unit_complex})"
@@ -198,3 +198,14 @@ class SE2(_base.MatrixLieGroup):
             rotation=self.rotation.normalize(),
             translation=self.translation,
         )
+
+    @staticmethod
+    @overrides
+    def sample_uniform(key: jax.random.PRNGKey) -> "SE2":
+        key0, key1 = jax.random.split(key)
+        return SE2.from_rotation_and_translation(
+            rotation=SO2.sample_uniform(key0),
+            translation=jax.random.uniform(
+                key=key1, shape=(2,), minval=-1.0, maxval=1.0
+            ),
+        )
