@@ -1,5 +1,6 @@
 import dataclasses
 
+import jax
 import numpy as onp
 from jax import numpy as jnp
 from overrides import overrides
@@ -24,7 +25,7 @@ class SO2(_base.MatrixLieGroup):
     """Internal parameters. `(cos, sin)`."""
 
     @overrides
-    def __repr__(self):
+    def __repr__(self) -> str:
         unit_complex = jnp.round(self.unit_complex, 5)
         return f"{self.__class__.__name__}(unit_complex={unit_complex})"
 
@@ -34,7 +35,7 @@ class SO2(_base.MatrixLieGroup):
         sin = jnp.sin(theta)
         return SO2(unit_complex=jnp.array([cos, sin]))
 
-    def to_radians(self) -> float:
+    def as_radians(self) -> float:
         (radians,) = self.log()
         return radians
 
@@ -102,3 +103,10 @@ class SO2(_base.MatrixLieGroup):
     @overrides
     def normalize(self: "SO2") -> "SO2":
         return SO2(unit_complex=self.unit_complex / jnp.linalg.norm(self.unit_complex))
+
+    @staticmethod
+    @overrides
+    def sample_uniform(key: jax.random.PRNGKey) -> "SO2":
+        return SO2.from_radians(
+            jax.random.uniform(key=key, minval=0.0, maxval=2 * jnp.pi)
+        )
