@@ -1,5 +1,6 @@
 import dataclasses
 
+import jax
 import numpy as onp
 from jax import numpy as jnp
 from overrides import overrides
@@ -24,7 +25,7 @@ class SO3(_base.MatrixLieGroup):
     """Internal parameters. `(w, x, y, z)` quaternion."""
 
     @overrides
-    def __repr__(self):
+    def __repr__(self) -> str:
         wxyz = jnp.round(self.wxyz, 5)
         return f"{self.__class__.__name__}(wxyz={wxyz})"
 
@@ -112,7 +113,7 @@ class SO3(_base.MatrixLieGroup):
 
     @staticmethod
     @overrides
-    def from_matrix(matrix: types.Matrix, method="day") -> "SO3":
+    def from_matrix(matrix: types.Matrix) -> "SO3":
         assert matrix.shape == (3, 3)
 
         # Modified from:
@@ -293,3 +294,28 @@ class SO3(_base.MatrixLieGroup):
     @overrides
     def normalize(self: "SO3") -> "SO3":
         return SO3(wxyz=self.wxyz / jnp.linalg.norm(self.wxyz))
+
+    @staticmethod
+    @overrides
+    def sample_uniform(key: jax.random.PRNGKey) -> "SO3":
+        # Uniformly sample over S^4
+        # > Reference: http://planning.cs.uiuc.edu/node198.html
+        u1, u2, u3 = jax.random.uniform(
+            key=key,
+            shape=(3,),
+            minval=jnp.zeros(3),
+            maxval=jnp.array([1.0, 2.0 * jnp.pi, 2.0 * jnp.pi]),
+        )
+        a = jnp.sqrt(1.0 - u1)
+        b = jnp.sqrt(u1)
+
+        return SO3(
+            wxyz=jnp.array(
+                [
+                    a * jnp.sin(u2),
+                    a * jnp.cos(u2),
+                    b * jnp.sin(u3),
+                    b * jnp.cos(u3),
+                ]
+            )
+        )
